==> deepin-ocr_1.0.0.orig.tar.xz: deepin-ocr-1.0.0/translations/deepin-ocr_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>MainWidget</name>
    <message>
        <source>Recognizing</source>
        <translation>正在识别</translation>
    </message>
    <message>
        <source>Copied</source>
        <translation>已复制</translation>
    </message>
    <message>
        <source>No text recognized</source>
        <translation>未识别到文字</translation>
    </message>
    <message>
        <source>Copy text</source>
        <translation>复制文字</translation>
    </message>
    <message>
        <source>Save as TXT</source>
        <translation>保存为TXT</translation>
    </message>
    <message>
        <source>Results</source>
        <translation>识别结果</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>OCR Tool</source>
        <translation>图文识别工具</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <source>SelectAll</source>
        <translation>全选</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>Widget</source>
        <translatorcomment>窗口</translatorcomment>
        <translation>Widget</translation>
    </message>
    <message>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>温馨提示：图像越简洁清晰，识别越准确</translation>
    </message>
</context>
</TS>

==> deepin-ocr_1.0.7.orig.tar.xz: deepin-ocr-1.0.7/translations/deepin-ocr_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>No text recognized</source>
        <translation>未识别到文字</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="214"/>
        <source>Copy text</source>
        <translation>复制文字</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="221"/>
        <source>Save as TXT</source>
        <translation>保存为TXT</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="273"/>
        <location filename="../src/mainwidget.cpp" line="314"/>
        <source>Recognizing</source>
        <translation>正在识别</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="514"/>
        <source>Copied</source>
        <translation>已复制</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="75"/>
        <source>OCR Tool</source>
        <translation>图文识别工具</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="24"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="27"/>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="29"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="262"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>温馨提示：图像越简洁清晰，识别越准确</translation>
    </message>
</context>
</TS>
